#[non_exhaustive]pub enum GameError {
RollPending,
ActionPending,
KeptNotHeld {
kept: Keep,
},
KeepNotInDice {
keep: Keep,
},
NoRerollsLeft,
IllegalCategory {
category: Category,
},
Finished,
}Expand description
A rules violation, reported without changing the game.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RollPending
Game::act was called while dice were due.
ActionPending
Game::roll was called while a decision was due.
KeptNotHeld
The injected roll does not contain the dice held from last roll.
KeepNotInDice
The kept dice are not a subset of the dice on the table.
NoRerollsLeft
A reroll was requested after the third roll.
IllegalCategory
The category is filled, or the joker rule forces another.
Finished
The game is over.